==> mx-locale_24.5.02.tar.xz: BUILD/translations/mx-locale_ru_RU.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru_RU">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>Program_Name</source>
        <translation>Название программы</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="46"/>
        <source>Quit application</source>
        <translation>Выйти из приложения</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="49"/>
        <source>Close</source>
        <translation>Закрыть</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="55"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="93"/>
        <source>About this application</source>
        <translation>Об этом приложении</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="96"/>
        <source>About...</source>
        <translation>О программе...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="102"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="118"/>
        <source>Display help </source>
        <translation>Показать справку</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="121"/>
        <source>Help</source>
        <translation>Помощь</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="127"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <source>System Locale</source>
        <extracomment> language selection, also default for locale subvariables if not otherwise defined</extracomment>
        <translation type="vanished">Системная локаль</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="214"/>
        <source>PushButton</source>
        <translation>НажатьКнопку</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="207"/>
        <source>Current System Language:</source>
        <translation>Текущий язык системы</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="181"/>
        <source>System Language</source>
        <extracomment> language selection, also default for locale subvariables if not otherwise defined</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="187"/>
        <source>Set all locale categories to current language</source>
        <translation>Установите все локальные категории на текущий язык.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="229"/>
        <source>Locale Categories</source>
        <extracomment>defines individual subvariables for locale</extracomment>
        <translation>Категории локали</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="255"/>
        <source>Numeric</source>
        <translation>Числовой</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="269"/>
        <source>Time</source>
        <translation>Время</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="283"/>
        <source>Collate</source>
        <translation>Сопоставить</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="297"/>
        <source>Currency</source>
        <translation>Валюта</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="311"/>
        <source>Messages</source>
        <translation>Сообщения</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="325"/>
        <source>Paper Size</source>
        <translation>Размер бумаги</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="339"/>
        <source>Name Style</source>
        <translation>Стиль имени</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="353"/>
        <source>Address</source>
        <translation>Адрес</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="367"/>
        <source>Telephone</source>
        <translation>Телефон</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="381"/>
        <source>Measurement</source>
        <translation>Измерение</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="413"/>
        <source>Locale Management</source>
        <extracomment>Tab to manage generation of locale caches</extracomment>
        <translation>Управление локализацией</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="465"/>
        <location filename="../mainwindow.ui" line="469"/>
        <location filename="../mainwindow.cpp" line="341"/>
        <source>All</source>
        <extracomment>elements of filter box</extracomment>
        <translation>Всех</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="474"/>
        <location filename="../mainwindow.cpp" line="291"/>
        <source>Enabled</source>
        <translation>Включено</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="479"/>
        <location filename="../mainwindow.cpp" line="290"/>
        <source>Disabled</source>
        <translation>Отключено</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="445"/>
        <source>Disable all locales except the one in use</source>
        <extracomment>disables generation of any locale except on that is currently in use</extracomment>
        <translation>Отключить все локали, кроме используемой.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="428"/>
        <source>search</source>
        <translation>поиск</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="455"/>
        <source>Reset locale list to default</source>
        <translation>Сбросить список локалей на значения по умолчанию</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="221"/>
        <source>Remove MX manuals for languages other than system default</source>
        <translation>Удалить руководства MX для языков, отличных от системных по умолчанию.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="498"/>
        <source>Changes go into effect on login</source>
        <translation>Изменения вступают в силу при входе в систему</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="74"/>
        <source>MX Locale</source>
        <translation>MX Локаль</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="142"/>
        <source>About %1</source>
        <translation>О %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="144"/>
        <source>Version: </source>
        <translation>Версия: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="145"/>
        <source>Program for changing language and locale categories</source>
        <translation>Программа для изменения языка и категорий локали.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="149"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="150"/>
        <source>%1 License</source>
        <translation>%1 Лицензия</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="157"/>
        <source>%1 Help</source>
        <translation>%1 Справка</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="261"/>
        <source>Locale in use: &lt;b&gt;%1&lt;/b&gt;</source>
        <comment>shows the current system locale, in bold</comment>
        <translation>Используемая локаль: &lt;b&gt;%1&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="283"/>
        <location filename="../mainwindow.cpp" line="289"/>
        <source>All</source>
        <comment>all as in everything</comment>
        <translation>Всех</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="306"/>
        <location filename="../mainwindow.cpp" line="352"/>
        <location filename="../mainwindow.cpp" line="358"/>
        <location filename="../mainwindow.cpp" line="364"/>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="307"/>
        <source>Can&apos;t disable locale in use</source>
        <comment>message that the chosen locale cannot be disabled because it is in active usage</comment>
        <translation>Невозможно отключить используемую локаль</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="339"/>
        <source>Locales enabled: %1</source>
        <comment>label for a numerical count of enabled and available locales</comment>
        <translation>Локали включены: %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="352"/>
        <location filename="../mainwindow.cpp" line="358"/>
        <location filename="../mainwindow.cpp" line="364"/>
        <source>Could not open %1</source>
        <translation>Не удалось открыть %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="392"/>
        <source>Locales enabled: %1</source>
        <translation>Локали включены: %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="401"/>
        <source>Updating locales, please wait</source>
        <translation>Обновление локалей, пожалуйста, подождите</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="447"/>
        <source>Removing packages, please wait</source>
        <translation>Удаление пакетов, пожалуйста, подождите</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="35"/>
        <source>License</source>
        <translation>Лицензия</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="36"/>
        <location filename="../about.cpp" line="46"/>
        <source>Changelog</source>
        <translation>Список изменений</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="37"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="55"/>
        <source>&amp;Close</source>
        <translation>&amp;Закрыть</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="57"/>
        <source>MX Locale is a tool used for managing locale settings in MX Linux</source>
        <translation>MX Locale - это инструмент, используемый для управления настройками локали в MX Linux.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="60"/>
        <source>Show only language selection tab.</source>
        <translation>Показывать только вкладку выбора языка.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="61"/>
        <source>Show all locale categories.</source>
        <translation>Показать все категории локали.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="71"/>
        <location filename="../main.cpp" line="79"/>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="72"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>Программа запущена суперпользователем. Для использования программы войдите в систему как обычный пользователь.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="80"/>
        <source>You must run this program with admin access.</source>
        <translation>Вы должны запустить эту программу с правами администратора.</translation>
    </message>
</context>
<context>
    <name>chooseDialog</name>
    <message>
        <location filename="../choosedialog.ui" line="14"/>
        <source>Dialog</source>
        <translation>Диалоговое окно</translation>
    </message>
    <message>
        <location filename="../choosedialog.ui" line="48"/>
        <source>search</source>
        <translation>поиск</translation>
    </message>
    <message>
        <location filename="../choosedialog.ui" line="58"/>
        <source>If your desired language is not listed here, enable it in &quot;Locale management&quot; tab</source>
        <translation>Если ваш язык не указан здесь, включите его во вкладке &quot;Управление локализацией&quot;</translation>
    </message>
    <message>
        <location filename="../choosedialog.cpp" line="25"/>
        <source>MX Locale</source>
        <comment>name of application</comment>
        <translation>MX Локаль</translation>
    </message>
    <message>
        <location filename="../choosedialog.cpp" line="40"/>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <location filename="../choosedialog.cpp" line="41"/>
        <source>Could not open %1</source>
        <comment>message that a file could not be open, file takes place of %1</comment>
        <translation>Не удалось открыть %1</translation>
    </message>
</context>
</TS>

==> mx-locale_25.4.tar.xz: BUILD/translations/mx-locale_ru_RU.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru_RU">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>Program_Name</source>
        <translation>Название программы</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="46"/>
        <source>Quit application</source>
        <translation>Выйти из приложения</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="49"/>
        <source>Close</source>
        <translation>Закрыть</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="55"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="93"/>
        <source>About this application</source>
        <translation>Об этом приложении</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="96"/>
        <source>About...</source>
        <translation>О программе...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="102"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="118"/>
        <source>Display help </source>
        <translation>Показать справку</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="121"/>
        <source>Help</source>
        <translation>Помощь</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="127"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="214"/>
        <source>PushButton</source>
        <translation>НажатьКнопку</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="207"/>
        <source>Current System Language:</source>
        <translation>Текущий язык системы</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="181"/>
        <source>System Language</source>
        <extracomment> language selection, also default for locale subvariables if not otherwise defined</extracomment>
        <translation>Системный язык</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="187"/>
        <source>Set all locale categories to current language</source>
        <translation>Установите все локальные категории на текущий язык.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="229"/>
        <source>Locale Categories</source>
        <extracomment>defines individual subvariables for locale</extracomment>
        <translation>Категории локали</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="255"/>
        <source>Numeric</source>
        <translation>Числовой</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="269"/>
        <source>Time</source>
        <translation>Время</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="283"/>
        <source>Collate</source>
        <translation>Сопоставить</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="297"/>
        <source>Currency</source>
        <translation>Валюта</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="311"/>
        <source>Messages</source>
        <translation>Сообщения</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="325"/>
        <source>Paper Size</source>
        <translation>Размер бумаги</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="339"/>
        <source>Name Style</source>
        <translation>Стиль имени</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="353"/>
        <source>Address</source>
        <translation>Адрес</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="367"/>
        <source>Telephone</source>
        <translation>Телефон</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="381"/>
        <source>Measurement</source>
        <translation>Измерение</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="413"/>
        <source>Locale Management</source>
        <extracomment>Tab to manage generation of locale caches</extracomment>
        <translation>Управление локализацией</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="465"/>
        <location filename="../mainwindow.ui" line="469"/>
        <location filename="../mainwindow.cpp" line="352"/>
        <source>All</source>
        <extracomment>elements of filter box</extracomment>
        <translation>Всех</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="474"/>
        <location filename="../mainwindow.cpp" line="293"/>
        <source>Enabled</source>
        <translation>Включено</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="479"/>
        <location filename="../mainwindow.cpp" line="292"/>
        <source>Disabled</source>
        <translation>Отключено</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="445"/>
        <source>Disable all locales except the one in use</source>
        <extracomment>disables generation of any locale except on that is currently in use</extracomment>
        <translation>Отключить все локали, кроме используемой.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="428"/>
        <source>search</source>
        <translation>поиск</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="455"/>
        <source>Reset locale list to default</source>
        <translation>Сбросить список локалей на значения по умолчанию</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="221"/>
        <source>Remove MX manuals for languages other than system default</source>
        <translation>Удалить руководства MX для языков, отличных от системных по умолчанию.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="498"/>
        <source>Changes go into effect on login</source>
        <translation>Изменения вступают в силу при входе в систему</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="79"/>
        <source>MX Locale</source>
        <translation>MX Локаль</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="153"/>
        <source>About %1</source>
        <translation>О %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="155"/>
        <source>Version: </source>
        <translation>Версия: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="156"/>
        <source>Program for changing language and locale categories</source>
        <translation>Программа для изменения языка и категорий локали.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="160"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="161"/>
        <source>%1 License</source>
        <translation>%1 Лицензия</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="168"/>
        <source>%1 Help</source>
        <translation>%1 Справка</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="267"/>
        <source>Locale in use: &lt;b&gt;%1&lt;/b&gt;</source>
        <comment>shows the current system locale, in bold</comment>
        <translation>Используемая локаль: &lt;b&gt;%1&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="283"/>
        <source>All</source>
        <comment>all as in everything</comment>
        <translation>Всех</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="318"/>
        <location filename="../mainwindow.cpp" line="375"/>
        <location filename="../mainwindow.cpp" line="390"/>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="319"/>
        <source>Can&apos;t disable locale in use</source>
        <comment>message that the chosen locale cannot be disabled because it is in active usage</comment>
        <translation>Невозможно отключить используемую локаль</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="350"/>
        <source>Locales enabled: %1</source>
        <comment>label for a numerical count of enabled and available locales</comment>
        <translation>Локали включены: %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="375"/>
        <location filename="../mainwindow.cpp" line="390"/>
        <source>Could not open %1</source>
        <translation>Не удалось открыть %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="459"/>
        <source>Locales enabled: %1</source>
        <translation>Локали включены: %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="468"/>
        <source>Updating locales, please wait</source>
        <translation>Обновление локалей, пожалуйста, подождите</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="519"/>
        <source>Remove Manuals</source>
        <translation>Удалить руководства</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="519"/>
        <source>No manuals to remove.</source>
        <translation>Нет руководств для удаления.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="526"/>
        <source>Removing packages, please wait</source>
        <translation>Удаление пакетов, пожалуйста, подождите</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="70"/>
        <source>License</source>
        <translation>Лицензия</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="71"/>
        <location filename="../about.cpp" line="81"/>
        <source>Changelog</source>
        <translation>Список изменений</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="72"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="94"/>
        <source>&amp;Close</source>
        <translation>&amp;Закрыть</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="68"/>
        <source>MX Locale is a tool used for managing locale settings in MX Linux</source>
        <translation>MX Locale - это инструмент, используемый для управления настройками локали в MX Linux.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="71"/>
        <source>Show only language selection tab.</source>
        <translation>Показывать только вкладку выбора языка.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="72"/>
        <source>Show all locale categories.</source>
        <translation>Показать все категории локали.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="82"/>
        <location filename="../main.cpp" line="90"/>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="83"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>Программа запущена суперпользователем. Для использования программы войдите в систему как обычный пользователь.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="91"/>
        <source>You must run this program with admin access.</source>
        <translation>Вы должны запустить эту программу с правами администратора.</translation>
    </message>
</context>
<context>
    <name>chooseDialog</name>
    <message>
        <location filename="../choosedialog.ui" line="14"/>
        <source>Dialog</source>
        <translation>Диалоговое окно</translation>
    </message>
    <message>
        <location filename="../choosedialog.ui" line="48"/>
        <source>search</source>
        <translation>поиск</translation>
    </message>
    <message>
        <location filename="../choosedialog.ui" line="58"/>
        <source>If your desired language is not listed here, enable it in &quot;Locale management&quot; tab</source>
        <translation>Если ваш язык не указан здесь, включите его во вкладке &quot;Управление локализацией&quot;</translation>
    </message>
    <message>
        <location filename="../choosedialog.cpp" line="25"/>
        <source>MX Locale</source>
        <comment>name of application</comment>
        <translation>MX Локаль</translation>
    </message>
    <message>
        <location filename="../choosedialog.cpp" line="40"/>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <location filename="../choosedialog.cpp" line="41"/>
        <source>Could not open %1</source>
        <comment>message that a file could not be opened, file takes place of %1</comment>
        <translation type="unfinished">Не удалось открыть %1</translation>
    </message>
    <message>
        <source>Could not open %1</source>
        <comment>message that a file could not be open, file takes place of %1</comment>
        <translation type="vanished">Не удалось открыть %1</translation>
    </message>
</context>
</TS>
